@@ -1,6 +1,6 @@
 ######################################################################
 #                                                                    #
-#  Copyright 2009-2020 Lucas Heitzmann Gabrielli.                    #
+#  Copyright 2009 Lucas Heitzmann Gabrielli.                         #
 #  This file is part of gdspy, distributed under the terms of the    #
 #  Boost Software License - Version 1.0.  See the accompanying       #
 #  LICENSE file or <http://www.boost.org/LICENSE_1_0.txt>            #
@@ -13,6 +13,7 @@ from __future__ import print_function
 from __future__ import absolute_import
 
 import sys
+import warnings
 
 if sys.version_info.major < 3:
     from builtins import zip
@@ -266,7 +267,7 @@ class Label(object):
                 )
         outfile.write(struct.pack(">2H", 4, 0x1100))
 
-    def to_svg(self, outfile, scaling):
+    def to_svg(self, outfile, scaling, precision):
         """
         Write an SVG fragment representation of this object.
 
@@ -276,22 +277,45 @@ class Label(object):
             Output to write the SVG representation.
         scaling : number
             Scaling factor for the geometry.
+        precision : positive integer or `None`
+            Maximal number of digits for coordinates after scaling.
         """
         transform = "scale(1 -1) translate({} {})".format(
-            scaling * self.position[0], -scaling * self.position[1]
+            numpy.format_float_positional(
+                scaling * self.position[0], trim="0", precision=precision
+            ),
+            numpy.format_float_positional(
+                -scaling * self.position[1], trim="0", precision=precision
+            ),
         )
         if self.rotation is not None:
-            transform += " rotate({})".format(-self.rotation)
+            transform += " rotate({})".format(
+                numpy.format_float_positional(
+                    -self.rotation, trim="0", precision=precision
+                )
+            )
         if self.x_reflection:
             transform += " scale(1 -1)"
         if self.magnification is not None:
-            transform += " scale({})".format(self.magnification)
+            transform += " scale({})".format(
+                numpy.format_float_positional(
+                    self.magnification, trim="0", precision=precision
+                )
+            )
         ta = ["start", "middle", "end"][self.anchor % 4]
         da = ["text-before-edge", "central", "text-after-edge"][self.anchor // 4]
+        if sys.version_info.major < 3:
+            text = (
+                self.text.decode("utf8")
+                .translate({38: "&amp;", 60: "&lt;", 62: "&gt;"})
+                .encode("utf8")
+            )
+        else:
+            text = self.text.translate({38: "&amp;", 60: "&lt;", 62: "&gt;"})
         outfile.write(
             '<text class="l{}t{}" text-anchor="{}" dominant-baseline="{}" '
             'transform="{}">{}</text>\n'.format(
-                self.layer, self.texttype, ta, da, transform, self.text
+                self.layer, self.texttype, ta, da, transform, text
             )
         )
 
